import { IconDefinition } from '@fortawesome/fontawesome-svg-core';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'tag',
  text: 'default-tag',
  textColor: colors.theme.white,
  textSize: '1rem',
  icon: fontawesome.icons.faXmark,
  iconSize: '1.30rem',
  iconColor: colors.theme.white,
  backgroundColor: colors.theme.blue,
  disableClose: true,
  onClickClose: () => {
    alert('clicked to close!');
  },
};

type TagProps = {
  className?: string;
  text?: string;
  textColor?: string;
  textSize?: string;
  icon?: IconDefinition;
  iconSize?: string;
  iconColor?: string;
  backgroundColor?: string;
  disableClose?: boolean;
  onClickClose?: () => void;
} & typeof defaultProps;

function Tag(props: TagProps) {
  const {
    className,
    text,
    textColor,
    textSize,
    icon,
    iconSize,
    iconColor,
    backgroundColor,
    disableClose,
    onClickClose,
  } = props;

  const styles = {
    tagContainer: {
      backgroundColor: `${backgroundColor}`,
      borderRadius: '0.375rem',
      display: 'inline-flex',
      margin: '0.219rem',
    },
    tagText: {
      fontStyle: 'roboto',
      fontWeight: '400',
      fontSize: `${textSize}`,
      color: `${textColor}`,
      padding: '0.19rem 0.313rem 0.25rem 0.313rem',
    },
    tagIcon: {
      color: `${iconColor}`,
      fontSize: `${iconSize}`,
      cursor: 'pointer',
      margin: '0.4rem 0.5rem 0.2rem 0.375rem',
    },
  };

  return (
    <div className={className} style={styles.tagContainer}>
      <span style={styles.tagText}>#{text}</span>
      {!disableClose && (
        <FontAwesomeIcon
          icon={icon}
          style={styles.tagIcon}
          onClick={onClickClose}
        />
      )}
    </div>
  );
}

Tag.defaultProps = defaultProps;
export default Tag;
