import React, { useState, useEffect, useRef } from 'react';

const defaultProps = {
  placeholder: 'Algum texto',
  textAreaWidth: '10em',
};

type TextAreaProps = {
  placeholder?: string;
  textAreaWidth?: string;
} & typeof defaultProps;

function TextArea(props: TextAreaProps) {
  const { placeholder, textAreaWidth } = props;

  const textAreaRef = useRef<HTMLTextAreaElement>(null);
  const [text, setText] = useState('');
  const [textAreaHeight, setTextAreaHeight] = useState('auto');
  const [parentHeight, setParentHeight] = useState('auto');

  useEffect(() => {
    setParentHeight(`${textAreaRef.current?.scrollHeight}px`);
    setTextAreaHeight(`${textAreaRef.current?.scrollHeight}px`);
  }, [text]);

  const onChangeHandler = (event: React.ChangeEvent<HTMLTextAreaElement>) => {
    setTextAreaHeight('auto');
    setParentHeight(`${textAreaRef.current?.scrollHeight}px`);
    setText(event.target.value);
  };

  const styles = {
    textArea: {
      margin: '0.5em',
      fontStyle: 'roboto',
      border: '0.1em solid #ccc',
      borderRadius: '0.3em',
      width: textAreaWidth,
      height: textAreaHeight,
      overflow: 'hidden',
    },
  };

  return (
    <div
      style={{
        minHeight: parentHeight,
      }}
    >
      <textarea
        ref={textAreaRef}
        rows={1}
        style={styles.textArea}
        onChange={onChangeHandler}
        placeholder={placeholder}
      />
    </div>
  );
}

TextArea.defaultProps = defaultProps;

export default TextArea;
