import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'textField',
  placeholder: 'Digite alguma coisa aqui',
  textColor: colors.theme.text_icon,
  borderColor: colors.theme.text_icon,
  fontSize: '1em',
  width: '20.1875em',
  height: '3.25em',
  margin: '1.5625em 0em 0em 0em',
  borderRadius: '0.3125em',
  onChange: () => {
    console.log('mudou');
  },
};

type TextFieldProps = {
  className?: string;
  placeholder?: string;
  textColor?: string;
  borderColor?: string;
  fontSize?: string;
  width?: string;
  height?: string;
  margin?: string;
  borderRadius?: string;
  onChange?: () => void;
} & typeof defaultProps;

function TextField(props: TextFieldProps) {
  const {
    className,
    placeholder,
    textColor,
    borderColor,
    fontSize,
    width,
    height,
    margin,
    borderRadius,
    onChange,
  } = props;

  const styles = {
    input: {
      fontSize,
      fontStyle: 'roboto',
      marginTop: '0.5rem',
      borderColor: `${borderColor}`,
      color: `${textColor}`,
      borderRadius,
      padding: '1.0625em 1.0625em 1.0625em 1.0625em',
      width,
      height,
      fontWeight: '400',
      margin,
      spellCheck: 'false',
      outline: 'none',
    },
    form: {
      textAlign: 'center' as const,
    },
  };

  return (
    <form style={styles.form}>
      <input
        style={styles.input}
        className={className}
        onChange={onChange}
        type="text"
        placeholder={placeholder}
      />
    </form>
  );
}
TextField.defaultProps = defaultProps;

export default TextField;
